@@ -5,7 +5,7 @@ from .myqt import QT
 
 from spikeinterface.widgets.utils import get_unit_colors
 from spikeinterface.toolkit import (get_template_extremum_channel, get_template_channel_sparsity,
-    compute_correlograms, compute_unit_centers_of_mass, compute_num_spikes, WaveformPrincipalComponent,
+    compute_correlograms, localize_unit, compute_num_spikes, WaveformPrincipalComponent,
     compute_template_similarity)
 
 import numpy as np
@@ -29,11 +29,22 @@ class  SpikeinterfaceController(ControllerBase):
             print(f'You should re run the WaveformExtractor with max_spikes_per_unit=500')
         
         
-        if (self.we.folder / 'PCA').is_dir():
-            self.pc = WaveformPrincipalComponent.load_from_folder(self.we.folder)
+        if waveform_extractor.is_extension('principal_components'):
+            self.pc = waveform_extractor.load_extension('principal_components')
         else:
             self.pc = None
-        
+
+        if waveform_extractor.is_extension('quality_metrics'):
+            qmc = waveform_extractor.load_extension('quality_metrics')
+            self.metrics = qmc._metrics
+        else:
+            self.metrics = None
+
+        if waveform_extractor.is_extension('spike_amplitudes'):
+            sac = waveform_extractor.load_extension('spike_amplitudes')
+            self.spike_amplitudes = sac.get_amplitudes(outputs='by_unit')
+        else:
+            self.spike_amplitudes = None
         
         # some direct attribute
         self.num_segments = self.we.recording.get_num_segments()
@@ -116,8 +127,9 @@ class  SpikeinterfaceController(ControllerBase):
         
         self.visible_channel_inds = np.arange(self.we.recording.get_num_channels(), dtype='int64')
         
-        coms = compute_unit_centers_of_mass(self.we, peak_sign='neg', num_channels=10)
-        self.unit_positions = np.vstack([coms[u] for u in self.unit_ids])
+        # simple unit position (can be computed later)
+        self.unit_positions = localize_unit(self.we, method='center_of_mass',  num_channels=10)
+        
 
         if verbose:
             t1 = time.perf_counter()
@@ -236,6 +248,12 @@ class  SpikeinterfaceController(ControllerBase):
         
     def set_channel_visibility(self, visible_channel_inds):
         self.visible_channel_inds = np.array(visible_channel_inds, copy=True)
+
+    def handle_metrics(self):
+        return self.metrics is not None
+
+    def handle_spike_amplitudes(self):
+        return self.spike_amplitudes is not None
         
     def handle_principal_components(self):
         return self.pc is not None
@@ -267,5 +285,9 @@ class  SpikeinterfaceController(ControllerBase):
     
     def get_sparsity_mask(self):
         return self.sparsity_mask
-
+    
+    def compute_unit_positions(self, method, method_kwargs):
+        self.unit_positions = localize_unit(self.we, method=method, **method_kwargs)
+        # 2D only
+        self.unit_positions = self.unit_positions[:, :2]
 
